/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dnd.gef;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.EditPart;
import org.fortiss.tooling.kernel.extension.data.IConnectionCompositionContext;

/**
 * A {@link ConnectionDragContext} stores information obtained from user's drag
 * gesture, i.e. the source edit part and the location w.r.t. this edit part and
 * the target edit part and the location w.r.t. this edit part.
 * <p>
 * This information is usually provided to the connection compositor in order to provide the UI data
 * necessary to construct layout information based on the drag gesture positions.
 * <p>
 * Note that this context is used for drag operations within a single editor, e.g. from one
 * displayed edit part to another in the same diagram.
 * 
 * @see ConnectionDropContext
 * @see ElementDropContext
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: EF7265719C3B49520F381A5B16DAFF7C
 */
public class ConnectionDragContext implements IConnectionCompositionContext {

	/** Source edit part. */
	private final EditPart source;

	/** Source position. */
	private final Point sourcePosition;

	/** Target edit part. */
	private EditPart target;

	/** Target position. */
	private Point targetPosition;

	/** Constructor. */
	public ConnectionDragContext(EditPart source, Point sourcePosition, EditPart target,
			Point targetPosition) {
		this.source = source;
		this.sourcePosition = sourcePosition;
		this.target = target;
		this.targetPosition = targetPosition;
	}

	/** Constructor. */
	public ConnectionDragContext(EditPart source, Point sourcePosition) {
		this(source, sourcePosition, null, null);
	}

	/**
	 * Set target data.
	 */
	public void setTarget(EditPart target, Point targetPosition) {
		this.target = target;
		this.targetPosition = targetPosition;
	}

	/** Returns the source position. */
	public Point getSourcePosition() {
		return sourcePosition;
	}

	/** Returns the source edit part. */
	public EditPart getSource() {
		return source;
	}

	/** Returns the target position. */
	public Point getTargetPosition() {
		return targetPosition;
	}

	/** Returns the target edit part. */
	public EditPart getTarget() {
		return target;
	}

	/** Returns the corresponding source DropContext. */
	public ElementDropContext getSourceDropContext() {
		return new ElementDropContext(getSource(), getSourcePosition());
	}

	/** Returns the corresponding source DropContext. */
	public ElementDropContext getTargetDropContext() {
		return new ElementDropContext(getTarget(), getTargetPosition());
	}
}
