/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.command;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.commands.Command;
import org.fortiss.tooling.base.ui.dnd.gef.ConnectionDragContext;
import org.fortiss.tooling.base.ui.editpart.policy.DirectConnectionAndReconnectionEditPolicy;
import org.fortiss.tooling.kernel.service.IConnectionCompositorService;

/**
 * This command is used by {@link DirectConnectionAndReconnectionEditPolicy} to
 * communicate with {@link IConnectionCompositorService} for creating new
 * connections.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 19A76A681820E49F4E8397BA1AB5358E
 */
public class ConnectCommand extends Command {

	/** Stores DropContext information. */
	protected final ConnectionDragContext context;

	/** Constructor. */
	public ConnectCommand(ConnectionDragContext context) {
		this.context = context;
	}

	/** Sets the target edit part and location. */
	public void setTarget(EditPart targetObject, Point targetLocation) {
		context.setTarget(targetObject, targetLocation);
	}

	/** {@inheritDoc} */
	@Override
	public boolean canExecute() {
		if(context == null || context.getSource() == null || context.getTarget() == null) {
			return false;
		}
		if(context.getSource().getModel() instanceof EObject &&
				context.getTarget().getModel() instanceof EObject &&
				context.getSource().getParent().getModel() instanceof EObject) {
			return IConnectionCompositorService.INSTANCE.canConnect((EObject)context.getSource()
					.getModel(), (EObject)context.getTarget().getModel(), (EObject)context
					.getSource().getParent().getModel(), context);
		}
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public void execute() {
		EObject sourceParent = (EObject)context.getSource().getParent().getModel();
		EObject targetParent = (EObject)context.getTarget().getParent().getModel();

		EObject commonParent = findCommonParent(sourceParent, targetParent);
		IConnectionCompositorService.INSTANCE.connect((EObject)context.getSource().getModel(),
				(EObject)context.getTarget().getModel(), commonParent, context);
	}

	/** Finds the common parent of two elements. */
	private EObject findCommonParent(EObject sourceParent, EObject targetParent) {
		if(sourceParent == targetParent) {
			return sourceParent;
		}
		if(sourceParent.eContainer() == targetParent) {
			return targetParent;
		}

		if(sourceParent == targetParent.eContainer())
			return sourceParent;

		return sourceParent.eContainer();
	}
}
